preflight

package
v1.10.2-dev-20260125 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 22, 2026 License: Apache-2.0 Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Checker

type Checker struct {
	CheckerCmdOptions
	// contains filtered or unexported fields
}

Checker provide functions for the preflight check.

func (*Checker) Cleanup

func (remote *Checker) Cleanup() error

Cleanup deletes the DaemonSet created for the preflight check.

func (*Checker) Init

func (remote *Checker) Init() error

Init initializes the Checker.

func (*Checker) Run

func (remote *Checker) Run() (string, error)

Run creates the DaemonSet for the preflight check, and waits for it to complete.

type CheckerCmdOptions

type CheckerCmdOptions struct {
	types.GlobalCmdOptions

	EnableSpdk      bool
	HugePageSize    int
	UserspaceDriver string
}

CheckerCmdOptions holds the options for the command.

type Installer

type Installer struct {
	InstallerCmdOptions
	// contains filtered or unexported fields
}

Installer provide functions for the preflight install.

func (*Installer) Cleanup

func (remote *Installer) Cleanup() error

Cleanup deletes the DaemonSet created for the preflight install when it's installed with package manager.

func (*Installer) Init

func (remote *Installer) Init() error

Init initializes the Installer.

func (*Installer) InstallByContainerOptimizedOS

func (remote *Installer) InstallByContainerOptimizedOS() error

InstallByContainerOptimizedOS installs the dependencies on Container Optimized OS. It creates a ConfigMap and a DaemonSet. Then it waits for the DaemonSet to be ready.

func (*Installer) InstallByPackageManager

func (remote *Installer) InstallByPackageManager() (string, error)

InstallByPackageManager installs the dependencies with package manager. It creates a DaemonSet. Then it waits for the DaemonSet to complete and return the logs of output container within the DaemonSet, for example: ip-192-168-208-117:

info:
- Successfully installed package nfs-client
- Successfully installed package open-iscsi
- Successfully installed package cryptsetup
- Successfully probed module nfs
- Successfully probed module iscsi_tcp
- Successfully probed module dm_crypt
- Successfully started service iscsid

func (*Installer) Run

func (remote *Installer) Run() (string, error)

Run creates the DaemonSet for the preflight install. It checks if the operating system is specified, and installs the dependencies accordingly. If the operating system is not specified, it installs the dependencies with package manager.

type InstallerCmdOptions

type InstallerCmdOptions struct {
	types.GlobalCmdOptions

	OperatingSystem string

	UpdatePackages       bool
	EnableSpdk           bool
	SpdkOptions          string
	HugePageSize         int
	AllowPci             string
	DriverOverride       string
	RestartKubelet       bool
	RestartKubeletWindow string
}

InstallerCmdOptions holds the options for the command.

Jump to